@@ -1,5 +1,7 @@
 from probability.distributions.discrete.beta_binomial import BetaBinomial
 from probability.distributions.discrete.binomial import Binomial
 from probability.distributions.discrete.geometric import Geometric
-from probability.distributions.discrete.negative_binomial import NegativeBinomial
+from probability.distributions.discrete.hyper_geometric import HyperGeometric
+from probability.distributions.discrete.negative_binomial import \
+    NegativeBinomial
 from probability.distributions.discrete.poisson import Poisson
