@@ -3,11 +3,12 @@ from typing import Union
 from scipy.stats import poisson, rv_discrete
 
 from compound_types.built_ins import FloatIterable
+from probability.custom_types.external_custom_types import FloatArray1d
 from probability.distributions.mixins.attributes import LambdaFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import \
     RVDiscrete1dMixin
-from probability.utils import num_format
+from probability.utils import num_format, is_scalar
 
 
 class Poisson(
@@ -52,7 +53,7 @@ class Poisson(
         return int(self._lambda)
 
     @staticmethod
-    def fit(data: FloatIterable) -> 'Poisson':
+    def fit(data: FloatArray1d) -> 'Poisson':
         """
         Fit a Poisson distribution to the data using the method of moments.
 
@@ -67,7 +68,7 @@ class Poisson(
         return Poisson(lambda_=lambda_)
 
     @staticmethod
-    def fits(data: FloatIterable) -> 'Poisson':
+    def fits(data: FloatArray1d) -> 'Poisson':
         """
         Fit a Poisson distribution to the data using the method of moments.
 
@@ -91,7 +92,7 @@ class Poisson(
 
     def __eq__(self, other: Union['Poisson', int, float]):
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return self.pmf().at(other)
         else:
             return abs(self._lambda - other._lambda) < 1e-10
@@ -100,7 +101,7 @@ class Poisson(
             self, other: Union['Poisson', int, float]
     ) -> Union[bool, float]:
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return 1 - self.pmf().at(other)
         else:
             return not self.__eq__(other)
